ProgressBar

Struct ProgressBar 

pub struct ProgressBar;
A simple progress bar that can be used to show the progress of something.

The input source should resolve to an f32 in the range 0.0..1.0.

Example

Vertical progress bar bound to a value source

ProgressBar::vertical(cx, AppData::progress);

Horizontal progress bar bound to a value source

ProgressBar::horizontal(cx, AppData::progress);

A horizontal progress bar with a label beside it

HStack::new(cx, |cx| {
    ProgressBar::horizontal(cx, AppData::progress);
    Label::new(cx, AppData::progress.map(|v| format!("{:.0}%", v * 100.0)));
});

Implementations

Source

impl ProgressBar

pub fn new<L>(cx: &mut Context, signal: L) -> Handle<'_, Self>
where L: SignalGet<f32> + SignalMap<f32>,

Creates a new progress bar bound to the provided value source.

Example
ProgressBar::new(cx, AppData::value);
pub fn horizontal<L>(cx: &mut Context, signal: L) -> Handle<'_, Self>
where L: SignalGet<f32> + SignalMap<f32>,

Creates a new horizontal progress bar bound to the provided value source.

pub fn vertical<L>(cx: &mut Context, signal: L) -> Handle<'_, Self>
where L: SignalGet<f32> + SignalMap<f32>,

Creates a new vertical progress bar bound to the provided value source.