pub struct ProgressBar;Expand description
A simple progress bar that can be used to show the progress of something.
The input source should resolve to an f32 in the range 0.0..1.0.
Example
Vertical progress bar bound to a value source
ⓘ
ProgressBar::vertical(cx, AppData::progress);Horizontal progress bar bound to a value source
ⓘ
ProgressBar::horizontal(cx, AppData::progress);A horizontal progress bar with a label beside it
ⓘ
HStack::new(cx, |cx| {
ProgressBar::horizontal(cx, AppData::progress);
Label::new(cx, AppData::progress.map(|v| format!("{:.0}%", v * 100.0)));
});Implementations